@@ -25,9 +25,11 @@ from .invoice_settings_api import InvoiceSettingsApi
 from .invoices_api import InvoicesApi
 from .manage_webhooks_api import ManageWebhooksApi
 from .merchant_boarding_api import MerchantBoardingApi
+from .merchant_defined_fields_api import MerchantDefinedFieldsApi
 from .microform_integration_api import MicroformIntegrationApi
 from .net_fundings_api import NetFundingsApi
 from .notification_of_changes_api import NotificationOfChangesApi
+from .offers_api import OffersApi
 from .payer_authentication_api import PayerAuthenticationApi
 from .payment_batch_summaries_api import PaymentBatchSummariesApi
 from .payment_instrument_api import PaymentInstrumentApi
@@ -55,6 +57,7 @@ from .unified_checkout_capture_context_api import UnifiedCheckoutCaptureContextA
 from .user_management_api import UserManagementApi
 from .user_management_search_api import UserManagementSearchApi
 from .verification_api import VerificationApi
+from .bank_account_validation_api import BankAccountValidationApi
 from .billing_agreements_api import BillingAgreementsApi
 from .capture_api import CaptureApi
 from .credit_api import CreditApi
