@@ -99,3 +99,7 @@ class GlobalLabelParameters:
     MESSAGE_AFTER_MLE_REQUEST = "Request after MLE: "
     MLE_CACHE_IDENTIFIER_FOR_CONFIG_CERT = "mleCertFromMerchantConfig"
     MLE_CACHE_IDENTIFIER_FOR_P12_CERT = "mleCertFromP12"
+    DEFAULT_MAX_IDLE_CONNECTIONS = 100
+    DEFAULT_MAX_POOL_SIZE = 10
+    DEFAULT_MAX_KEEP_ALIVE_DELAY = 300 # in seconds
+    DEFAULT_MAX_KEEP_ALIVE_IDLE_WINDOW = 60 # in seconds
